@@ -22,12 +22,15 @@
 #include "bits.h"
 
 #ifdef IN_DXF_H
-#error in_dxf.h must be included after out_json.h because of FORMAT_BD
+#  error in_dxf.h must be included after out_json.h because of FORMAT_BD
 #endif
 
 EXPORT int dwg_write_json (Bit_Chain *restrict dat, Dwg_Data *restrict dwg);
 EXPORT int dwg_write_geojson (Bit_Chain *restrict dat, Dwg_Data *restrict dwg);
 
-char *json_cquote (char *restrict dest, const char *restrict src, const int len);
+// converts a TV to a UTF-8 string (with codepage conversion) and quoting
+// ", \n \r, U+XXXX
+char *json_cquote (char *restrict dest, const char *restrict src,
+                   const size_t len, const BITCODE_RS codepage);
 
 #endif
