@@ -11,11 +11,12 @@ api_process (dwg_object *obj)
   BITCODE_BL class_version;
 
   Dwg_Version_Type dwg_version = obj->parent->header.version;
-  dwg_obj_assocnetworksurfaceactionbody *_obj = dwg_object_to_ASSOCNETWORKSURFACEACTIONBODY (obj);
+  dwg_obj_assocnetworksurfaceactionbody *_obj
+      = dwg_object_to_ASSOCNETWORKSURFACEACTIONBODY (obj);
 
   // ASSOCACTIONBODY
   CHK_ENTITY_TYPE (_obj, ASSOCNETWORKSURFACEACTIONBODY, aab_version, BL);
-  CHK_ENTITY_MAX  (_obj, ASSOCNETWORKSURFACEACTIONBODY, aab_version, BL, 2);
+  CHK_ENTITY_MAX (_obj, ASSOCNETWORKSURFACEACTIONBODY, aab_version, BL, 2);
   CHK_ASSOCPARAMBASEDACTIONBODY (ASSOCNETWORKSURFACEACTIONBODY);
   // AcDbAssocSurfaceActionBody
   CHK_SUBCLASS_TYPE (_obj->sab, ASSOCSURFACEACTIONBODY, version, BL);
@@ -23,9 +24,9 @@ api_process (dwg_object *obj)
   CHK_SUBCLASS_TYPE (_obj->sab, ASSOCSURFACEACTIONBODY, l2, BL);
   CHK_SUBCLASS_TYPE (_obj->sab, ASSOCSURFACEACTIONBODY, is_semi_ovr, B);
   CHK_SUBCLASS_TYPE (_obj->sab, ASSOCSURFACEACTIONBODY, grip_status, BS);
-  CHK_SUBCLASS_H    (_obj->sab, ASSOCSURFACEACTIONBODY, assocdep);
+  CHK_SUBCLASS_H (_obj->sab, ASSOCSURFACEACTIONBODY, assocdep);
   // AcDbAssocPathBasedSurfaceActionBody
   CHK_ENTITY_TYPE (_obj, ASSOCNETWORKSURFACEACTIONBODY, pbsab_status, BL);
 
-  CHK_ENTITY_TYPE (_obj, ASSOCNETWORKSURFACEACTIONBODY, class_version, BL); 
+  CHK_ENTITY_TYPE (_obj, ASSOCNETWORKSURFACEACTIONBODY, class_version, BL);
 }
