@@ -9,14 +9,14 @@ api_process (dwg_object *obj)
   BITCODE_BL i;
   BLOCKACTION_fields;
   BITCODE_BL numelems; /* computed */
-  BITCODE_BL numrows; /* DXF 92 */
-  BITCODE_BL numcols; /* DXF 93 */
+  BITCODE_BL numrows;  /* DXF 92 */
+  BITCODE_BL numcols;  /* DXF 93 */
   Dwg_BLOCKLOOKUPACTION_lut *lut;
   BITCODE_T *exprs;
   BITCODE_B b280;
 
   Dwg_Version_Type dwg_version = obj->parent->header.version;
-#ifdef DEBUG_CLASSES
+  // #ifdef DEBUG_CLASSES
   dwg_obj_blocklookupaction *_obj = dwg_object_to_BLOCKLOOKUPACTION (obj);
 
   // AcDbBlockAction
@@ -33,16 +33,19 @@ api_process (dwg_object *obj)
       fail ("BLOCKLOOKUPACTION.lut[]: NULL");
       return;
     }
-  for (i = 0; i < numrows * numcols; i++) {
-    for (int j = 0; j < 3; j++)
-      {
-        CHK_SUBCLASS_TYPE     (_obj->lut[i].conn_pts[j], BLOCKACTION_connectionpts, code, BL);
-        CHK_SUBCLASS_UTF8TEXT (_obj->lut[i].conn_pts[j], BLOCKACTION_connectionpts, name);
-      }
-    CHK_SUBCLASS_TYPE     (_obj->lut[i], "BLOCKLOOKUPACTION_lut", b282, BL);
-    CHK_SUBCLASS_TYPE     (_obj->lut[i], "BLOCKLOOKUPACTION_lut", b281, BL);
-  }
+  for (i = 0; i < numrows * numcols; i++)
+    {
+      for (int j = 0; j < 3; j++)
+        {
+          CHK_SUBCLASS_TYPE (_obj->lut[i].conn_pts[j],
+                             BLOCKACTION_connectionpts, code, BL);
+          CHK_SUBCLASS_UTF8TEXT (_obj->lut[i].conn_pts[j],
+                                 BLOCKACTION_connectionpts, name);
+        }
+      CHK_SUBCLASS_TYPE (_obj->lut[i], "BLOCKLOOKUPACTION_lut", b282, BL);
+      CHK_SUBCLASS_TYPE (_obj->lut[i], "BLOCKLOOKUPACTION_lut", b281, BL);
+    }
   CHK_ENTITY_TYPE (_obj, BLOCKLOOKUPACTION, b280, B);
   // ..
-#endif
+  // #endif
 }
