@@ -1,8 +1,21 @@
 #define DECODE_TEST_C
+#define _DEFAULT_SOURCE 1
+#if defined(__linux__)
+#  define _GNU_SOURCE 1 /* for memmem on linux */
+#endif
+#define _BSD_SOURCE 1
+#ifdef __STDC_ALLOC_LIB__
+#  define __STDC_WANT_LIB_EXT2__ 1 /* for strdup */
+#else
+#  define _USE_BSD 1
+#endif
+
+#define IS_DECODER
+#include <stdlib.h>
 #include "../../src/common.h"
-CLANG_DIAG_IGNORE (-Wpragma-pack)
-#include "../../src/decode.c"
-CLANG_DIAG_RESTORE
+// CLANG_DIAG_IGNORE (-Wpragma-pack)
+#include "decode.c"
+// CLANG_DIAG_RESTORE
 #include "tests_common.h"
 
 void read_literal_length_tests (void);
@@ -19,6 +32,7 @@ read_literal_length_tests (void)
     ok ("read_literal_length");
   else
     fail ("read_literal_length");
+  bitfree (&bitchain);
 }
 
 void
@@ -26,13 +40,10 @@ read_long_compression_offset_tests (void)
 {
   Bit_Chain bitchain = strtobt ("11011101");
   if (read_long_compression_offset (&bitchain) == 0xDD)
-    {
-      pass ();
-    }
+    pass ();
   else
-    {
-      fail ("read_long_compression_offset");
-    }
+    fail ("read_long_compression_offset");
+  bitfree (&bitchain);
 }
 
 /* This functions calls tests for read_two_byte_offset()
@@ -44,18 +55,17 @@ read_two_byte_offset_tests (void)
   unsigned int litlength = 0x03;
   int result = read_two_byte_offset (&bitchain, &litlength);
   if (result == 508 && litlength == 0)
-    {
-      pass ();
-    }
+    pass ();
   else
-    {
-      fail ("read_two_byte_offset");
-    }
+    fail ("read_two_byte_offset");
+  bitfree (&bitchain);
 }
 
 int
 main (int argc, char const *argv[])
 {
+  loglevel = is_make_silent () ? 0 : 2;
+
   read_literal_length_tests ();
   read_long_compression_offset_tests ();
   read_two_byte_offset_tests ();
